==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Effect/ladspa/translations/ladspa_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>EffectLADSPAFactory</name>
    <message>
        <location filename="../effectladspafactory.cpp" line="31"/>
        <source>LADSPA Plugin</source>
        <translation>Engadido LADSPA</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="51"/>
        <source>About LADSPA Host for Qmmp</source>
        <translation>Sobre LADSPA Host para Qmmp</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="52"/>
        <source>LADSPA Host for Qmmp</source>
        <translation>LADSPA Host para Qmmp</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="54"/>
        <source>Based on the LADSPA Host for BMP</source>
        <translation>Baseado no LADSPA Host para BMP</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="55"/>
        <source>BMP-ladspa developers:</source>
        <translation>Desenvolvedores de BMP-ladspa:</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="56"/>
        <source>Nick Lamb &lt;njl195@zepler.org.uk&gt;</source>
        <translation>Nick Lamb &lt;njl195@zepler.org.uk&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="57"/>
        <source>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</source>
        <translation>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>LADSPA Plugin Catalog</source>
        <translation>Catálogo do engadido LADSPA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>This LADSPA plugin has no user controls</source>
        <translation>Este engadido LADSPA non ten controis de usuario</translation>
    </message>
</context>
</TS>

==> qmmp_1.3.4.orig.tar.bz2: qmmp-1.3.4/src/plugins/Effect/ladspa/translations/ladspa_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>EffectLADSPAFactory</name>
    <message>
        <location filename="../effectladspafactory.cpp" line="30"/>
        <source>LADSPA Plugin</source>
        <translation>Engadido LADSPA</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="50"/>
        <source>About LADSPA Host for Qmmp</source>
        <translation>Sobre LADSPA Host para Qmmp</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="51"/>
        <source>LADSPA Host for Qmmp</source>
        <translation>LADSPA Host para Qmmp</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="53"/>
        <source>Based on the LADSPA Host for BMP</source>
        <translation>Baseado no LADSPA Host para BMP</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="54"/>
        <source>BMP-ladspa developers:</source>
        <translation>Desenvolvedores de BMP-ladspa:</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="55"/>
        <source>Nick Lamb &lt;njl195@zepler.org.uk&gt;</source>
        <translation>Nick Lamb &lt;njl195@zepler.org.uk&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="56"/>
        <source>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</source>
        <translation>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>LADSPA Plugin Catalog</source>
        <translation>Catálogo do engadido LADSPA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>This LADSPA plugin has no user controls</source>
        <translation>Este engadido LADSPA non ten controis de usuario</translation>
    </message>
</context>
</TS>
